Modules
=======

Evolvable module architectures implemented: (More coming soon!)
    * MLP
    * CNN
    * LSTM
    * MultiInput
    * Transformers - GPT and BERT

We are constantly adding more neural network architectures, so keep an eye out for updates!

.. toctree::
   :maxdepth: 1

   base
   mlp
   cnn
   lstm
   multi_input
   simba
   resnet
   dummy
   gpt
   bert
   custom_activation
